panko
=====


-------------
Documentation
-------------

Documentation for the project can be found at:
https://docs.openstack.org/panko/latest/

Launchpad Projects
------------------
- Server: https://launchpad.net/panko
- Client: https://launchpad.net/python-pankoclient

Code Repository
---------------
- Server: https://github.com/openstack/panko
- Client: https://github.com/openstack/python-pankoclient

Bug Tracking
------------
- Bugs: https://bugs.launchpad.net/panko

IRC
---
IRC Channel: #openstack-telemetry on Freenode.

Release notes
-------------
Release notes: https://docs.openstack.org/releasenotes/panko/
